@@ -18,10 +18,11 @@ from cvxpy.atoms import (MatrixFrac, Pnorm, QuadForm, abs, bmat, conj, conv,
                          cumsum, imag, kron, lambda_max, lambda_sum_largest,
                          log_det, norm1, norm_inf, quad_over_lin, real,
                          reshape, sigma_max, trace, upper_tri,
-                         von_neumann_entr,)
+                         von_neumann_entr, quantum_rel_entr)
 from cvxpy.atoms.affine.add_expr import AddExpression
 from cvxpy.atoms.affine.binary_operators import (DivExpression, MulExpression,
                                                  multiply,)
+from cvxpy.atoms.affine.broadcast_to import broadcast_to
 from cvxpy.atoms.affine.diag import diag_mat, diag_vec
 from cvxpy.atoms.affine.hstack import Hstack
 from cvxpy.atoms.affine.index import index, special_index
@@ -30,6 +31,7 @@ from cvxpy.atoms.affine.sum import Sum
 from cvxpy.atoms.affine.transpose import transpose
 from cvxpy.atoms.affine.unary_operators import NegExpression
 from cvxpy.atoms.affine.vstack import Vstack
+from cvxpy.atoms.affine.concatenate import Concatenate
 from cvxpy.atoms.affine.wraps import hermitian_wrap
 from cvxpy.atoms.norm_nuc import normNuc
 from cvxpy.constraints import (PSD, SOC, Equality, Inequality,
@@ -49,7 +51,7 @@ from cvxpy.reductions.complex2real.canonicalizers.inequality_canon import (
 from cvxpy.reductions.complex2real.canonicalizers.matrix_canon import (
     hermitian_canon, lambda_sum_largest_canon, matrix_frac_canon,
     norm_nuc_canon, op_rel_entr_cone_canon, quad_canon, quad_over_lin_canon,
-    trace_canon, von_neumann_entr_canon,)
+    trace_canon, von_neumann_entr_canon, quantum_rel_entr_canon)
 from cvxpy.reductions.complex2real.canonicalizers.param_canon import (
     param_canon,)
 from cvxpy.reductions.complex2real.canonicalizers.pnorm_canon import (
@@ -69,6 +71,7 @@ CANON_METHODS = {
     index: separable_canon,
     special_index: separable_canon,
     Promote: separable_canon,
+    broadcast_to: separable_canon,
     reshape: separable_canon,
     Sum: separable_canon,
     trace: trace_canon,
@@ -76,6 +79,7 @@ CANON_METHODS = {
     NegExpression: separable_canon,
     upper_tri: separable_canon,
     Vstack: separable_canon,
+    Concatenate: separable_canon,
 
     conv: binary_canon,
     DivExpression: binary_canon,
@@ -111,4 +115,5 @@ CANON_METHODS = {
     lambda_sum_largest: lambda_sum_largest_canon,
     OpRelEntrConeQuad: op_rel_entr_cone_canon,
     von_neumann_entr: von_neumann_entr_canon,
+    quantum_rel_entr: quantum_rel_entr_canon
 }
