@@ -74,6 +74,7 @@ GLPK_MI = "GLPK_MI"
 GLOP = "GLOP"
 CBC = "CBC"
 COPT = "COPT"
+CUOPT = "CUOPT"
 ECOS = "ECOS"
 ECOS_BB = "ECOS_BB"
 SCS = "SCS"
@@ -92,12 +93,16 @@ PDLP = "PDLP"
 SCIP = "SCIP"
 SCIPY = "SCIPY"
 CLARABEL = "CLARABEL"
+CUCLARABEL = "CUCLARABEL"
 DAQP = "DAQP"
 HIGHS = "HIGHS"
+MPAX = "MPAX"
 SOLVERS = [CLARABEL, ECOS, CVXOPT, GLOP, GLPK, GLPK_MI,
            SCS, SDPA, GUROBI, OSQP, CPLEX,
            MOSEK, CBC, COPT, XPRESS, PIQP, PROXQP, QOCO,
-           NAG, PDLP, SCIP, SCIPY, DAQP, HIGHS]
+           NAG, PDLP, SCIP, SCIPY, DAQP, HIGHS, MPAX,
+           CUCLARABEL, CUOPT]
+
 
 # Xpress-specific items
 XPRESS_IIS = "XPRESS_IIS"
