@@ -15,12 +15,14 @@ limitations under the License.
 """
 
 import numpy as np
+import pytest
 import scipy.sparse as sp
 
 import cvxpy as cp
 from cvxpy import Minimize, Problem
 from cvxpy.expressions.constants import Constant, Parameter
 from cvxpy.expressions.variable import Variable
+from cvxpy.reductions.solvers.defines import INSTALLED_MI_SOLVERS
 from cvxpy.tests.base_test import BaseTest
 
 
@@ -220,7 +222,7 @@ class TestComplex(BaseTest):
         x = Variable((2, 2))
         y = Variable((3, 2), complex=True)
         expr = cp.vstack([x, y])
-        prob = Problem(Minimize(cp.sum(cp.imag(expr.H))),
+        prob = Problem(Minimize(cp.sum(cp.imag(expr.T.conjugate()))),
                        [x == 0, cp.real(y) == 0, cp.imag(y) <= 1])
         result = prob.solve(solver="SCS", eps=1e-6)
         self.assertAlmostEqual(result, -6)
@@ -291,7 +293,7 @@ class TestComplex(BaseTest):
         """
         x = Variable((1, 2), complex=True)
         prob = Problem(cp.Maximize(cp.sum(cp.imag(x) + cp.real(x))), [cp.norm1(x) <= 2])
-        result = prob.solve(solver="ECOS")
+        result = prob.solve(solver=cp.CLARABEL)
         self.assertAlmostEqual(result, 2*np.sqrt(2))
         val = np.ones(2)*np.sqrt(2)/2
         # self.assertItemsAlmostEqual(x.value, val + 1j*val)
@@ -299,7 +301,7 @@ class TestComplex(BaseTest):
         x = Variable((2, 2), complex=True)
         prob = Problem(cp.Maximize(cp.sum(cp.imag(x) + cp.real(x))),
                        [cp.pnorm(x, p=2) <= np.sqrt(8)])
-        result = prob.solve(solver="ECOS")
+        result = prob.solve(solver=cp.CLARABEL)
         self.assertAlmostEqual(result, 8)
         val = np.ones((2, 2))
         self.assertItemsAlmostEqual(x.value, val + 1j*val)
@@ -388,7 +390,7 @@ class TestComplex(BaseTest):
         x = Variable(3, complex=False)
         value = cp.quad_form(b, P).value
         prob = Problem(cp.Minimize(cp.quad_form(x, P)), [x == b])
-        result = prob.solve(solver="ECOS")
+        result = prob.solve(solver="CLARABEL")
         self.assertAlmostEqual(result, value)
 
         # Solve a problem with complex variable
@@ -396,7 +398,7 @@ class TestComplex(BaseTest):
         x = Variable(3, complex=True)
         value = cp.quad_form(b, P).value
         prob = Problem(cp.Minimize(cp.quad_form(x, P)), [x == b])
-        result = prob.solve(solver="ECOS")
+        result = prob.solve(solver="CLARABEL")
         normalization = max(abs(result), abs(value))
         self.assertAlmostEqual(result / normalization, value / normalization, places=5)
 
@@ -406,7 +408,7 @@ class TestComplex(BaseTest):
         value = cp.quad_form(b, P).value
         expr = cp.quad_form(x, P)
         prob = Problem(cp.Minimize(expr), [x == b])
-        result = prob.solve(solver="ECOS")
+        result = prob.solve(solver="CLARABEL")
         normalization = max(abs(result), abs(value))
         self.assertAlmostEqual(result / normalization, value / normalization)
 
@@ -484,7 +486,7 @@ class TestComplex(BaseTest):
         obj = cp.Maximize(cp.real(cp.sum(v * np.ones((2, 2)))))
         con = [cp.norm(v) <= 1]
         prob = cp.Problem(obj, con)
-        result = prob.solve(solver="ECOS")
+        result = prob.solve(solver="CLARABEL")
         self.assertAlmostEqual(result, 4.0)
 
     def test_sparse(self) -> None:
@@ -494,7 +496,7 @@ class TestComplex(BaseTest):
         row = np.array([0, 1])
         col = np.array([1, 0])
         data = np.array([1j, -1j])
-        A = sp.csr_matrix((data, (row, col)), shape=(2, 2))
+        A = sp.csr_array((data, (row, col)), shape=(2, 2))
 
         # Feasibility with sparse matrix
         rho = cp.Variable((2, 2), complex=True)
@@ -526,7 +528,7 @@ class TestComplex(BaseTest):
         constraints = [f >> 0]
         for k in range(1, n):
             indices = [(i * n) + i - (n - k) for i in range(n - k, n)]
-            constraints += [cp.sum(cp.vec(f)[indices]) == c[n - k]]
+            constraints += [cp.sum(cp.vec(f, order='F')[indices]) == c[n - k]]
         # Form objective.
         obj = cp.Maximize(c[0] - cp.real(cp.trace(f)))
         # Form and solve problem.
@@ -637,6 +639,10 @@ class TestComplex(BaseTest):
         print("P2 is complex:", cp.quad_form(x, P2).curvature)
         assert cp.quad_form(x, P2).is_dcp()
 
+    @pytest.mark.skipif(
+        "HIGHS" not in INSTALLED_MI_SOLVERS, 
+        reason='HiGHS solver is not installed.'
+    )
     def test_bool(self) -> None:
         # The purpose of this test is to make sure
         # that we don't try to recover dual variables
@@ -652,7 +658,7 @@ class TestComplex(BaseTest):
 
         obj = cp.Maximize(cp.real(complex_var))
         prob = cp.Problem(obj, constraints)
-        prob.solve(solver='ECOS_BB')
+        prob.solve(solver=cp.HIGHS)
         self.assertAlmostEqual(prob.value, 1, places=4)
 
     def test_partial_trace(self) -> None:
