@@ -18,10 +18,10 @@ import builtins
 import pickle
 import sys
 import warnings
+from contextlib import redirect_stdout
 from fractions import Fraction
 from io import StringIO
 
-import ecos
 import numpy
 import numpy as np
 import scipy.sparse as sp
@@ -38,7 +38,7 @@ from cvxpy.error import DCPError, ParameterError, SolverError
 from cvxpy.expressions.constants import Constant, Parameter
 from cvxpy.expressions.variable import Variable
 from cvxpy.problems.problem import Problem
-from cvxpy.reductions.solvers.conic_solvers import ecos_conif, scs_conif
+from cvxpy.reductions.solvers.conic_solvers import scs_conif
 from cvxpy.reductions.solvers.conic_solvers.conic_solver import ConicSolver
 from cvxpy.reductions.solvers.defines import (
     INSTALLED_SOLVERS,
@@ -46,6 +46,7 @@ from cvxpy.reductions.solvers.defines import (
 )
 from cvxpy.reductions.solvers.solving_chain import ECOS_DEPRECATION_MSG
 from cvxpy.tests.base_test import BaseTest
+from cvxpy.utilities.citations import CITATION_DICT
 
 
 class TestProblem(BaseTest):
@@ -92,6 +93,13 @@ class TestProblem(BaseTest):
         ref = [self.a, self.x, self.b, self.A]
         self.assertCountEqual(vars_, ref)
 
+
+    def test_variables_with_value(self):
+        Variable(name="without_bounds", value=0.0)
+        Variable(name="with_none_bounds", value=0.0, bounds=None)
+        Variable(name="with_none_none_bounds", value=0.0, bounds=[None, None])
+
+
     def test_var_dict(self) -> None:
         p = Problem(cp.Minimize(self.a), [self.a <= self.x, self.b <= self.A + 2])
         assert p.var_dict == {"a": self.a, "x": self.x, "b": self.b, "A": self.A}
@@ -191,12 +199,10 @@ class TestProblem(BaseTest):
         """Test the solver_stats method.
         """
         prob = Problem(cp.Minimize(cp.norm(self.x)), [self.x == 0])
-        prob.solve(solver=s.ECOS)
+        prob.solve(solver=s.CLARABEL)
         stats = prob.solver_stats
         self.assertGreater(stats.solve_time, 0)
-        self.assertGreater(stats.setup_time, 0)
         self.assertGreater(stats.num_iters, 0)
-        self.assertIn('info', stats.extra_stats)
 
         prob = Problem(cp.Minimize(cp.norm(self.x)), [self.x == 0])
         prob.solve(solver=s.SCS)
@@ -230,12 +236,11 @@ class TestProblem(BaseTest):
         self.assertEqual(data["c"].shape, (2,))
         self.assertEqual(data["A"].shape, (3, 2))
 
-        data, _, _ = Problem(cp.Minimize(cp.norm(self.x) + 3)).get_problem_data(s.ECOS)
+        data, _, _ = Problem(cp.Minimize(cp.norm(self.x) + 3)).get_problem_data(s.CLARABEL)
         dims = data[ConicSolver.DIMS]
         self.assertEqual(dims.soc, [3])
         self.assertEqual(data["c"].shape, (3,))
-        self.assertIsNone(data["A"])
-        self.assertEqual(data["G"].shape, (3, 3))
+        self.assertEqual(data["A"].shape, (3, 3))
 
         # caching use_quad_obj
         p = Problem(cp.Minimize(cp.sum_squares(self.x) + 2))
@@ -260,6 +265,13 @@ class TestProblem(BaseTest):
             # offsets were correctly parsed until we update the CVXOPT
             # interface.
 
+        # Test with uncapitalized solver name.
+        data, _, _ = Problem(cp.Minimize(cp.norm(self.x) + 3)).get_problem_data("Clarabel")
+        dims = data[ConicSolver.DIMS]
+        self.assertEqual(dims.soc, [3])
+        self.assertEqual(data["c"].shape, (3,))
+        self.assertEqual(data["A"].shape, (3, 3))
+
     def test_unpack_results(self) -> None:
         """Test unpack results method.
         """
@@ -274,17 +286,6 @@ class TestProblem(BaseTest):
         self.assertAlmostEqual(prob.value, 1, places=3)
         self.assertAlmostEqual(prob.status, s.OPTIMAL)
 
-        prob = Problem(cp.Minimize(cp.norm(self.x)), [self.x == 0])
-        args, chain, inv = prob.get_problem_data(s.ECOS)
-        cones = ecos_conif.dims_to_solver_dict(args[ConicSolver.DIMS])
-        solution = ecos.solve(args["c"], args["G"], args["h"],
-                              cones, args["A"], args["b"])
-        prob = Problem(cp.Minimize(cp.norm(self.x)), [self.x == 0])
-        prob.unpack_results(solution, chain, inv)
-        self.assertItemsAlmostEqual(self.x.value, [0, 0])
-        self.assertAlmostEqual(prob.value, 0)
-        self.assertAlmostEqual(prob.status, s.OPTIMAL)
-
     def test_verbose(self) -> None:
         """Test silencing and enabling solver messages.
         """
@@ -316,7 +317,7 @@ class TestProblem(BaseTest):
                         p.solve(verbose=verbose, solver=solver)
 
                     if PSD in SOLVER_MAP_CONIC[solver].SUPPORTED_CONSTRAINTS:
-                        a_mat = cp.reshape(self.a, shape=(1, 1))
+                        a_mat = cp.reshape(self.a, shape=(1, 1), order='F')
                         p = Problem(cp.Minimize(self.a), [cp.lambda_min(a_mat) >= 2])
                         p.solve(verbose=verbose, solver=solver)
 
@@ -333,6 +334,53 @@ class TestProblem(BaseTest):
             print(solver)
             assert len(output) == 0
 
+    def test_solver_verbose(self) -> None:
+        """Test silencing and enabling solver-only messages.
+        """
+        # setup the environment
+        outputs = {True: [], False: []}
+        backup = sys.stdout
+        ######
+        for solver in INSTALLED_SOLVERS:
+            for solver_verbose in [True, False]:
+                # Don't test GLPK because there's a race
+                # condition in setting CVXOPT solver options.
+                if solver in [cp.GLPK, cp.GLPK_MI, cp.MOSEK, cp.CBC,
+                              cp.SCIPY, cp.COPT]:
+                    continue
+                sys.stdout = StringIO()  # capture output
+
+                p = Problem(cp.Minimize(self.a + self.x[0]),
+                            [self.a >= 2, self.x >= 2])
+                p.solve(solver_verbose=solver_verbose, solver=solver)
+
+                if solver in SOLVER_MAP_CONIC:
+                    if SOLVER_MAP_CONIC[solver].MIP_CAPABLE:
+                        p.constraints.append(Variable(boolean=True) == 0)
+                        p.solve(solver_verbose=solver_verbose, solver=solver)
+
+                    if ExpCone in SOLVER_MAP_CONIC[solver].SUPPORTED_CONSTRAINTS:
+                        p = Problem(cp.Minimize(self.a), [cp.log(self.a) >= 2])
+                        p.solve(solver_verbose=solver_verbose, solver=solver)
+
+                    if PSD in SOLVER_MAP_CONIC[solver].SUPPORTED_CONSTRAINTS:
+                        a_mat = cp.reshape(self.a, shape=(1, 1), order='F')
+                        p = Problem(cp.Minimize(self.a), [cp.lambda_min(a_mat) >= 2])
+                        p.solve(solver_verbose=solver_verbose, solver=solver)
+
+                out = sys.stdout.getvalue()  # release output
+                sys.stdout.close()  # close the stream
+                sys.stdout = backup  # restore original stdout
+
+                outputs[solver_verbose].append((out, solver))
+
+        for output, solver in outputs[True]:
+            print(solver)
+            assert len(output) > 0
+        for output, solver in outputs[False]:
+            print(solver)
+            assert len(output) == 0
+
     # Test registering other solve methods.
     def test_register_solve(self) -> None:
         Problem.register_solve("test", lambda self: 1)
@@ -351,6 +399,43 @@ class TestProblem(BaseTest):
         result = p.solve(1, method="test", b=4)
         self.assertEqual(result, (1, 4))
 
+    def test_bibtex(self) -> None:
+        """Test bibtex citations.
+        """
+
+        # Solve Disciplined Convex Program
+        p = Problem(cp.Minimize(self.a + self.x[0]),
+                    [self.a >= 2, self.x >= 2])
+        with redirect_stdout(StringIO()) as f:
+            p.solve(verbose=True, bibtex=True)
+        out = f.getvalue()
+        assert CITATION_DICT["CVXPY"] in out
+        assert CITATION_DICT["DCP"] in out
+
+        # Solve Disciplined Geometric Program
+        x = cp.Variable(pos=True)
+        y = cp.Variable(pos=True)
+        z = cp.Variable(pos=True)
+        objective_fn = x * y * z
+        constraints = [
+        4 * x * y * z + 2 * x * z <= 10, x <= 2*y, y <= 2*x, z >= 1]
+        problem = cp.Problem(cp.Maximize(objective_fn), constraints)
+        with redirect_stdout(StringIO()) as f:
+            problem.solve(verbose=True, bibtex=True, gp=True)
+        out = f.getvalue()
+        assert CITATION_DICT["CVXPY"] in out
+        assert CITATION_DICT["DGP"] in out
+
+        # Solve Disciplined Quasiconvex Program
+        x = cp.Variable()
+        expr = cp.ceil(x)
+        problem = cp.Problem(cp.Maximize(expr), [x >= 12, x <= 17])
+        with redirect_stdout(StringIO()) as f:
+            problem.solve(verbose=True, bibtex=True, qcp=True)
+        out = f.getvalue()
+        assert CITATION_DICT["CVXPY"] in out
+        assert CITATION_DICT["DQCP"] in out
+
     # def test_consistency(self):
     #     """Test that variables and constraints keep a consistent order.
     #     """
@@ -373,7 +458,7 @@ class TestProblem(BaseTest):
     #         obj = cp.Minimize(sum)
     #         p = Problem(obj, constraints)
     #         objective, constraints = p.canonicalize()
-    #         sym_data = SymData(objective, constraints, SOLVERS[s.ECOS])
+    #         sym_data = SymData(objective, constraints, SOLVERS[s.CLARABEL])
     #         # Sort by offset.
     #         vars_ = sorted(sym_data.var_offsets.items(),
     #                        key=lambda key_val: key_val[1])
@@ -534,19 +619,22 @@ class TestProblem(BaseTest):
         combo1 = prob1 + 2 * prob2
         combo1_ref = Problem(cp.Minimize(self.a + 4 * self.b),
                              [self.a >= self.b, self.a >= 1, self.b >= 2])
-        self.assertAlmostEqual(combo1.solve(solver=cp.ECOS), combo1_ref.solve(solver=cp.ECOS))
+        self.assertAlmostEqual(combo1.solve(solver=cp.CLARABEL),
+                               combo1_ref.solve(solver=cp.CLARABEL))
 
         # division and subtraction
         combo2 = prob1 - prob3/2
         combo2_ref = Problem(cp.Minimize(self.a + pow(self.b + self.a, 2)/2),
                              [self.b >= 3, self.a >= self.b])
-        self.assertAlmostEqual(combo2.solve(solver=cp.ECOS), combo2_ref.solve(solver=cp.ECOS))
+        self.assertAlmostEqual(combo2.solve(solver=cp.CLARABEL),
+                               combo2_ref.solve(solver=cp.CLARABEL))
 
         # multiplication with 0 (prob2's constraints should still hold)
         combo3 = prob1 + 0 * prob2 - 3 * prob3
         combo3_ref = Problem(cp.Minimize(self.a + 3 * pow(self.b + self.a, 2)),
                              [self.a >= self.b, self.a >= 1, self.b >= 3])
-        self.assertAlmostEqual(combo3.solve(solver=cp.ECOS), combo3_ref.solve(solver=cp.ECOS))
+        self.assertAlmostEqual(combo3.solve(solver=cp.CLARABEL),
+                               combo3_ref.solve(solver=cp.CLARABEL))
 
     # Test scalar LP problems.
     def test_scalar_lp(self) -> None:
@@ -576,7 +664,7 @@ class TestProblem(BaseTest):
         # Test status and value.
         exp = cp.Maximize(self.a)
         p = Problem(exp, [self.a <= 2])
-        result = p.solve(solver=s.ECOS)
+        result = p.solve(solver=s.CLARABEL)
         self.assertEqual(result, p.value)
         self.assertEqual(p.status, s.OPTIMAL)
         assert self.a.value is not None
@@ -584,7 +672,7 @@ class TestProblem(BaseTest):
 
         # Unbounded problems.
         p = Problem(cp.Maximize(self.a), [self.a >= 2])
-        p.solve(solver=s.ECOS)
+        p.solve(solver=s.CLARABEL)
         self.assertEqual(p.status, s.UNBOUNDED)
         assert numpy.isinf(p.value)
         assert p.value > 0
@@ -604,7 +692,7 @@ class TestProblem(BaseTest):
         self.a.save_value(2)
         p.constraints[0].save_dual_value(2)
 
-        result = p.solve(solver=s.ECOS)
+        result = p.solve(solver=s.CLARABEL)
         self.assertEqual(result, p.value)
         self.assertEqual(p.status, s.INFEASIBLE)
         assert numpy.isinf(p.value)
@@ -613,7 +701,7 @@ class TestProblem(BaseTest):
         assert p.constraints[0].dual_value is None
 
         p = Problem(cp.Minimize(-self.a), [self.a >= 2, self.a <= 1])
-        result = p.solve(solver=s.ECOS)
+        result = p.solve(solver=s.CLARABEL)
         self.assertEqual(result, p.value)
         self.assertEqual(p.status, s.INFEASIBLE)
         assert numpy.isinf(p.value)
@@ -641,12 +729,12 @@ class TestProblem(BaseTest):
         self.assertItemsAlmostEqual(self.x.value, [8, 8], places=3)
         self.assertItemsAlmostEqual(self.z.value, [2, 2], places=3)
 
-    def test_ecos_noineq(self) -> None:
-        """Test ECOS with no inequality constraints.
+    def test_CLARABEL_noineq(self) -> None:
+        """Test CLARABEL with no inequality constraints.
         """
         T = Constant(numpy.ones((2, 2))).value
         p = Problem(cp.Minimize(1), [self.A == T])
-        result = p.solve(solver=s.ECOS)
+        result = p.solve(solver=s.CLARABEL)
         self.assertAlmostEqual(result, 1)
         self.assertItemsAlmostEqual(self.A.value, T)
 
@@ -661,7 +749,7 @@ class TestProblem(BaseTest):
         T = Constant(numpy.ones((2, 3))*2).value
         p = Problem(cp.Minimize(1), [self.A >= T @ self.C,
                                      self.A == self.B, self.C == T.T])
-        result = p.solve(solver=cp.ECOS)
+        result = p.solve(solver=cp.CLARABEL)
         self.assertAlmostEqual(result, 1)
         self.assertItemsAlmostEqual(self.A.value, self.B.value)
         self.assertItemsAlmostEqual(self.C.value, T)
@@ -673,7 +761,7 @@ class TestProblem(BaseTest):
     # Test variable promotion.
     def test_variable_promotion(self) -> None:
         p = Problem(cp.Minimize(self.a), [self.x <= self.a, self.x == [1, 2]])
-        result = p.solve(solver=cp.ECOS)
+        result = p.solve(solver=cp.CLARABEL)
         self.assertAlmostEqual(result, 2)
         self.assertAlmostEqual(self.a.value, 2)
 
@@ -681,14 +769,14 @@ class TestProblem(BaseTest):
                     [self.A <= self.a,
                      self.A == [[1, 2], [3, 4]]
                      ])
-        result = p.solve(solver=cp.ECOS)
+        result = p.solve(solver=cp.CLARABEL)
         self.assertAlmostEqual(result, 4)
         self.assertAlmostEqual(self.a.value, 4)
 
         # Promotion must happen before the multiplication.
         p = Problem(cp.Minimize([[1], [1]] @ (self.x + self.a + 1)),
                     [self.a + self.x >= [1, 2]])
-        result = p.solve(solver=cp.ECOS)
+        result = p.solve(solver=cp.CLARABEL)
         self.assertAlmostEqual(result, 5)
 
     # Test parameter promotion.
@@ -744,7 +832,7 @@ class TestProblem(BaseTest):
         # Vector arguments.
         p = Problem(cp.Minimize(cp.norm_inf(self.x - self.z) + 5),
                     [self.x >= [2, 3], self.z <= [-1, -4]])
-        result = p.solve(solver=cp.ECOS)
+        result = p.solve(solver=cp.CLARABEL)
         self.assertAlmostEqual(float(result), 12)
         self.assertAlmostEqual(float(list(self.x.value)[1] - list(self.z.value)[1]), 7)
 
@@ -827,7 +915,7 @@ class TestProblem(BaseTest):
 
         with self.assertRaises(Exception) as cm:
             Problem(cp.Minimize(cp.quad_form(1, self.A))).solve(solver=cp.SCS, eps=1e-6)
-        self.assertEqual(str(cm.exception), "Invalid dimensions for arguments.")
+        self.assertEqual(str(cm.exception), "Invalid dimensions for arguments to quad_form.")
 
         with warnings.catch_warnings():
             warnings.simplefilter("ignore")
@@ -874,7 +962,7 @@ class TestProblem(BaseTest):
     def test_dual_variables(self) -> None:
         """Test recovery of dual variables.
         """
-        for solver in [s.ECOS, s.SCS, s.CVXOPT]:
+        for solver in [s.CLARABEL, s.SCS, s.CVXOPT]:
             if solver in INSTALLED_SOLVERS:
                 if solver == s.SCS:
                     acc = 1
@@ -938,13 +1026,8 @@ class TestProblem(BaseTest):
     def test_non_python_int_index(self) -> None:
         """Test problems that have special types as indices.
         """
-        import sys
-        if sys.version_info > (3,):
-            my_long = int
-        else:
-            my_long = long  # noqa: F821
-        # Test with long indices.
-        cost = self.x[0:my_long(2)][0]
+        # Test with int indices.
+        cost = self.x[0:int(2)][0]
         p = Problem(cp.Minimize(cost), [self.x == 1])
         result = p.solve(solver=cp.SCS)
         self.assertAlmostEqual(result, 1)
@@ -1046,7 +1129,7 @@ class TestProblem(BaseTest):
             problem.solve(solver=cp.SCS, eps=1e-5)
         self.assertTrue("Problem does not follow DCP rules."
                         in str(cm.exception))
-        
+
         # Test parametrized vstack
         p = Parameter((2, 1), value=np.array([[3], [3]]))
         q = Parameter((2, 1), value=np.array([[-8], [-8]]))
@@ -1209,17 +1292,6 @@ class TestProblem(BaseTest):
         result = p.solve(solver=s.SCS)
         self.assertAlmostEqual(result, 0)
 
-        with self.assertRaises(ValueError) as cm:
-            obj = cp.Minimize(cp.sum(cp.square(self.x)))
-            constraints = [self.x == self.x]
-            problem = Problem(obj, constraints)
-            problem.solve(solver=s.ECOS)
-        self.assertEqual(
-            str(cm.exception),
-            "ECOS cannot handle sparse data with nnz == 0; "
-            "this is a bug in ECOS, and it indicates that your problem "
-            "might have redundant constraints.")
-
     # Test that symmetry is enforced.
     def test_sdp_symmetry(self) -> None:
         p = Problem(cp.Minimize(cp.lambda_max(self.A)), [self.A >= 2])
@@ -1273,7 +1345,7 @@ class TestProblem(BaseTest):
         self.assertEqual(exp.value, 0)
         obj = cp.Minimize(exp)
         p = Problem(obj)
-        result = p.solve(solver=cp.ECOS)
+        result = p.solve(solver=cp.CLARABEL)
         self.assertAlmostEqual(result, 0)
         assert self.a.value is not None
 
@@ -1282,26 +1354,26 @@ class TestProblem(BaseTest):
         """
         obj = cp.Minimize(cp.norm_inf(self.A/5))
         p = Problem(obj, [self.A >= 5])
-        result = p.solve(solver=cp.ECOS)
+        result = p.solve(solver=cp.CLARABEL)
         self.assertAlmostEqual(result, 1)
 
         c = cp.Constant([[1., -1], [2, -2]])
         expr = self.A/(1./c)
         obj = cp.Minimize(cp.norm_inf(expr))
         p = Problem(obj, [self.A == 5])
-        result = p.solve(solver=cp.ECOS)
+        result = p.solve(solver=cp.CLARABEL)
         self.assertAlmostEqual(result, 10)
         self.assertItemsAlmostEqual(expr.value, [5, -5] + [10, -10])
 
         # Test with a sparse matrix.
         import scipy.sparse as sp
-        interface = intf.get_matrix_interface(sp.csc_matrix)
+        interface = intf.get_matrix_interface(sp.csc_array)
         c = interface.const_to_matrix([1, 2])
         c = cp.Constant(c)
         expr = self.x[:, None]/(1/c)
         obj = cp.Minimize(cp.norm_inf(expr))
         p = Problem(obj, [self.x == 5])
-        result = p.solve(solver=cp.ECOS)
+        result = p.solve(solver=cp.CLARABEL)
         self.assertAlmostEqual(result, 10)
         self.assertItemsAlmostEqual(expr.value, [5, 10])
 
@@ -1311,7 +1383,7 @@ class TestProblem(BaseTest):
         expr = self.a/(1/c)
         obj = cp.Minimize(cp.norm_inf(expr))
         p = Problem(obj, [self.a == 5])
-        result = p.solve(solver=cp.ECOS)
+        result = p.solve(solver=cp.CLARABEL)
         self.assertAlmostEqual(result, 10)
         self.assertItemsAlmostEqual(expr.value, [5, -5] + [10, -10])
 
@@ -1322,18 +1394,18 @@ class TestProblem(BaseTest):
         expr = cp.multiply(c, self.A)
         obj = cp.Minimize(cp.norm_inf(expr))
         p = Problem(obj, [self.A == 5])
-        result = p.solve(solver=cp.ECOS)
+        result = p.solve(solver=cp.CLARABEL)
         self.assertAlmostEqual(result, 10)
         self.assertItemsAlmostEqual(expr.value, [5, -5] + [10, -10])
 
         # Test with a sparse matrix.
         import scipy.sparse as sp
-        interface = intf.get_matrix_interface(sp.csc_matrix)
+        interface = intf.get_matrix_interface(sp.csc_array)
         c = interface.const_to_matrix([1, 2])
         expr = cp.multiply(c, self.x[:, None])
         obj = cp.Minimize(cp.norm_inf(expr))
         p = Problem(obj, [self.x == 5])
-        result = p.solve(solver=cp.ECOS)
+        result = p.solve(solver=cp.CLARABEL)
         self.assertAlmostEqual(result, 10)
         self.assertItemsAlmostEqual(expr.value.toarray(), [5, 10])
 
@@ -1350,10 +1422,10 @@ class TestProblem(BaseTest):
         """Tests that errors occur when you use an invalid solver.
         """
         with self.assertRaises(SolverError):
-            Problem(cp.Minimize(Variable(boolean=True))).solve(solver=s.ECOS)
+            Problem(cp.Minimize(Variable(boolean=True))).solve(solver=s.OSQP)
 
         with self.assertRaises(SolverError):
-            Problem(cp.Minimize(cp.lambda_max(self.A))).solve(solver=s.ECOS)
+            Problem(cp.Minimize(cp.lambda_max(self.A))).solve(solver=s.OSQP)
 
         with self.assertRaises(SolverError):
             Problem(cp.Minimize(self.a)).solve(solver=s.SCS)
@@ -1369,18 +1441,65 @@ class TestProblem(BaseTest):
                 cp.sum_squares(cp.matmul(A, cp.Variable(40)) - b))).solve(
                 solver=s.OSQP, max_iter=1)
 
+    def test_solve_solver_path(self) -> None:
+        """
+        Tests the solve_solver_path method under various conditions:
+
+        1. Verifies that a SolverError is raised when all solvers fail.
+        2. Validates that a solution is returned when any of the solvers succeeds.
+        3. Ensures that a ValueError is raised when the inner inputs of the solvers are invalid.
+
+        """
+
+        A = numpy.random.randn(40, 40)
+        b = cp.matmul(A, numpy.random.randn(40))
+
+        # valid input, return solution
+        solvers_with_str=[(s.OSQP, {'max_iter':1}), s.CLARABEL]
+        solvers_empty_dict=[(s.OSQP, {'max_iter':1}), (s.CLARABEL, {})]
+        solvers_wrong_case=[("osqp", {'max_iter':1}), "Clarabel"]
+
+        for solvers in [solvers_with_str, solvers_empty_dict, solvers_wrong_case]:
+            self.assertIsNotNone(Problem(cp.Minimize(
+                cp.sum_squares(cp.matmul(A, cp.Variable(40)) - b))).solve(
+                solver_path=solvers))
+
+        # valid input, raise SolverError
+        solvers = [(s.OSQP, {'max_iter':1})]
+
+        with self.assertRaises(SolverError):
+            Problem(cp.Minimize(
+                cp.sum_squares(cp.matmul(A, cp.Variable(40)) - b))).solve(
+                solver_path=solvers)
+
+        # invalid input, raise ValueError
+        solvers_invalid_inner_input = [{'str':{}}, 'str', [], [1], [()], [(1)], [(1,{})],
+                                        [(s.OSQP,[])], [(s.OSQP,)]]
+
+        for solvers in solvers_invalid_inner_input:
+            with self.assertRaises(ValueError):
+                Problem(cp.Minimize(
+                    cp.sum_squares(cp.matmul(A, cp.Variable(40)) - b))).solve(
+                    solver_path=solvers)
+
+        ## Specify both solver_path and solver as arguments
+        with self.assertRaises(ValueError):
+                Problem(cp.Minimize(
+                    cp.sum_squares(cp.matmul(A, cp.Variable(40)) - b))).solve(
+                    solver_path=[s.OSQP], solver=s.OSQP)
+
     def test_reshape(self) -> None:
         """Tests problems with reshape.
         """
         # Test on scalars.
-        self.assertEqual(cp.reshape(1, (1, 1)).value, 1)
+        self.assertEqual(cp.reshape(1, (1, 1), order='F').value, 1)
 
         # Test vector to matrix.
         x = Variable(4)
         mat = numpy.array([[1, -1], [2, -2]]).T
         vec = numpy.array([[1, 2, 3, 4]]).T
         vec_mat = numpy.array([[1, 2], [3, 4]]).T
-        expr = cp.reshape(x, (2, 2))
+        expr = cp.reshape(x, (2, 2), order='F')
         obj = cp.Minimize(cp.sum(mat @ expr))
         prob = Problem(obj, [x[:, None] == vec])
         result = prob.solve(solver=cp.SCS)
@@ -1388,36 +1507,36 @@ class TestProblem(BaseTest):
 
         # Test on matrix to vector.
         c = [1, 2, 3, 4]
-        expr = cp.reshape(self.A, (4, 1))
+        expr = cp.reshape(self.A, (4, 1), order='F')
         obj = cp.Minimize(expr.T @ c)
         constraints = [self.A == [[-1, -2], [3, 4]]]
         prob = Problem(obj, constraints)
         result = prob.solve(solver=cp.SCS)
         self.assertAlmostEqual(result, 20)
         self.assertItemsAlmostEqual(expr.value, [-1, -2, 3, 4])
-        self.assertItemsAlmostEqual(cp.reshape(expr, (2, 2)).value, [-1, -2, 3, 4])
+        self.assertItemsAlmostEqual(cp.reshape(expr, (2, 2), order='F').value, [-1, -2, 3, 4])
 
         # Test matrix to matrix.
-        expr = cp.reshape(self.C, (2, 3))
+        expr = cp.reshape(self.C, (2, 3), order='F')
         mat = numpy.array([[1, -1], [2, -2]])
         C_mat = numpy.array([[1, 4], [2, 5], [3, 6]])
         obj = cp.Minimize(cp.sum(mat @ expr))
         prob = Problem(obj, [self.C == C_mat])
         result = prob.solve(solver=cp.SCS)
-        reshaped = numpy.reshape(C_mat, (2, 3), 'F')
+        reshaped = numpy.reshape(C_mat, (2, 3), order='F')
         self.assertAlmostEqual(result, (mat.dot(reshaped)).sum())
         self.assertItemsAlmostEqual(expr.value, C_mat)
 
         # Test promoted expressions.
         c = numpy.array([[1, -1], [2, -2]]).T
-        expr = cp.reshape(c * self.a, (1, 4))
+        expr = cp.reshape(c * self.a, (1, 4), order='F')
         obj = cp.Minimize(expr @ [1, 2, 3, 4])
         prob = Problem(obj, [self.a == 2])
         result = prob.solve(solver=cp.SCS)
         self.assertAlmostEqual(result, -6)
         self.assertItemsAlmostEqual(expr.value, 2*c)
 
-        expr = cp.reshape(c * self.a, (4, 1))
+        expr = cp.reshape(c * self.a, (4, 1), order='F')
         obj = cp.Minimize(expr.T @ [1, 2, 3, 4])
         prob = Problem(obj, [self.a == 2])
         result = prob.solve(solver=cp.SCS)
@@ -1446,7 +1565,7 @@ class TestProblem(BaseTest):
         """Tests problems with vec.
         """
         c = [1, 2, 3, 4]
-        expr = cp.vec(self.A)
+        expr = cp.vec(self.A, order='F')
         obj = cp.Minimize(expr.T @ c)
         constraints = [self.A == [[-1, -2], [3, 4]]]
         prob = Problem(obj, constraints)
@@ -1722,7 +1841,7 @@ class TestProblem(BaseTest):
 
         for p in (1, 1.6, 1.3, 2, 1.99, 3, 3.7, np.inf):
             prob = Problem(cp.Minimize(cp.pnorm(x, p=p)), [x.T @ a >= 1])
-            prob.solve(solver=cp.ECOS, verbose=True)
+            prob.solve(solver=cp.CLARABEL, verbose=True)
 
             # formula is true for any a >= 0 with p > 1
             if p == np.inf:
@@ -1747,14 +1866,14 @@ class TestProblem(BaseTest):
         a = np.array([-1.0, 2, 3])
         for p in (-1, .5, .3, -2.3):
             prob = Problem(cp.Minimize(cp.sum(cp.abs(x-a))), [cp.pnorm(x, p) >= 0])
-            prob.solve(solver=cp.ECOS)
+            prob.solve(solver=cp.CLARABEL)
 
             self.assertTrue(np.allclose(prob.value, 1))
 
         a = np.array([1.0, 2, 3])
         for p in (-1, .5, .3, -2.3):
             prob = Problem(cp.Minimize(cp.sum(cp.abs(x-a))), [cp.pnorm(x, p) >= 0])
-            prob.solve(solver=cp.ECOS)
+            prob.solve(solver=cp.CLARABEL)
 
             self.assertAlmostEqual(prob.value, 0, places=6)
 
@@ -1819,7 +1938,7 @@ class TestProblem(BaseTest):
         con = [expr <= 0]
         obj = cp.Maximize(cp.sum(X))
         prob = cp.Problem(obj, con)
-        prob.solve(solver=cp.ECOS)
+        prob.solve(solver=cp.CLARABEL)
         self.assertItemsAlmostEqual(expr.value, numpy.zeros(2))
 
         b = numpy.arange(10)
@@ -1828,7 +1947,7 @@ class TestProblem(BaseTest):
         con = [expr <= 0]
         obj = cp.Maximize(cp.sum(X))
         prob = cp.Problem(obj, con)
-        prob.solve(solver=cp.ECOS)
+        prob.solve(solver=cp.CLARABEL)
         self.assertItemsAlmostEqual(expr.value, numpy.zeros(10))
 
     def test_bool_constr(self) -> None:
@@ -1836,41 +1955,41 @@ class TestProblem(BaseTest):
         """
         x = cp.Variable(pos=True)
         prob = cp.Problem(cp.Minimize(x), [True])
-        prob.solve(solver=cp.ECOS)
+        prob.solve(solver=cp.CLARABEL)
         self.assertAlmostEqual(x.value, 0)
 
         x = cp.Variable(pos=True)
         prob = cp.Problem(cp.Minimize(x), [True]*10)
-        prob.solve(solver=cp.ECOS)
+        prob.solve(solver=cp.CLARABEL)
         self.assertAlmostEqual(x.value, 0)
 
         prob = cp.Problem(cp.Minimize(x), [42 <= x] + [True]*10)
-        prob.solve(solver=cp.ECOS)
+        prob.solve(solver=cp.CLARABEL)
         self.assertAlmostEqual(x.value, 42)
 
         prob = cp.Problem(cp.Minimize(x), [True] + [42 <= x] + [True] * 10)
-        prob.solve(solver=cp.ECOS)
+        prob.solve(solver=cp.CLARABEL)
         self.assertAlmostEqual(x.value, 42)
 
         prob = cp.Problem(cp.Minimize(x), [False])
-        prob.solve(solver=cp.ECOS)
+        prob.solve(solver=cp.CLARABEL)
         self.assertEqual(prob.status, s.INFEASIBLE)
 
         prob = cp.Problem(cp.Minimize(x), [False]*10)
-        prob.solve(solver=cp.ECOS)
+        prob.solve(solver=cp.CLARABEL)
         self.assertEqual(prob.status, s.INFEASIBLE)
 
         prob = cp.Problem(cp.Minimize(x), [True]*10 + [False] + [True]*10)
-        prob.solve(solver=cp.ECOS)
+        prob.solve(solver=cp.CLARABEL)
         self.assertEqual(prob.status, s.INFEASIBLE)
 
         prob = cp.Problem(cp.Minimize(x), [42 <= x] + [True]*10 + [False])
-        prob.solve(solver=cp.ECOS)
+        prob.solve(solver=cp.CLARABEL)
         self.assertEqual(prob.status, s.INFEASIBLE)
 
         # only Trues, but infeasible solution since x must be non-negative.
         prob = cp.Problem(cp.Minimize(x), [True] + [x <= -42] + [True]*10)
-        prob.solve(solver=cp.ECOS)
+        prob.solve(solver=cp.CLARABEL)
         self.assertEqual(prob.status, s.INFEASIBLE)
 
     def test_invalid_constr(self) -> None:
@@ -1886,12 +2005,12 @@ class TestProblem(BaseTest):
         """
         x = cp.Variable(pos=True)
         prob = cp.Problem(cp.Minimize(x))
-        prob.solve(solver=cp.ECOS)
+        prob.solve(solver=cp.CLARABEL)
         self.assertAlmostEqual(x.value, 0)
 
         x = cp.Variable(neg=True)
         prob = cp.Problem(cp.Maximize(x))
-        prob.solve(solver=cp.ECOS)
+        prob.solve(solver=cp.CLARABEL)
         self.assertAlmostEqual(x.value, 0)
 
     def test_pickle(self) -> None:
@@ -1928,7 +2047,7 @@ class TestProblem(BaseTest):
             constraints = [a >= 0., -alpha <= D.T @ a, D.T @ a <= alpha]
 
             prob = cp.Problem(obj, constraints)
-            prob.solve(solver=cp.settings.ECOS)
+            prob.solve(solver=s.CLARABEL)
             assert prob.status == 'optimal'
             return prob
 
@@ -1938,11 +2057,11 @@ class TestProblem(BaseTest):
 
         make_problem(D_dense)
         coef_dense = a.value.T.dot(D_dense)
-        np.testing.assert_almost_equal(expected_coef, coef_dense)
+        np.testing.assert_almost_equal(expected_coef, coef_dense, decimal=4)
 
         make_problem(D_sparse)
         coef_sparse = a.value.T @ D_sparse
-        np.testing.assert_almost_equal(expected_coef, coef_sparse)
+        np.testing.assert_almost_equal(expected_coef, coef_sparse, decimal=4)
 
     def test_special_index(self) -> None:
         """Test QP code path with special indexing.
@@ -2007,9 +2126,9 @@ class TestProblem(BaseTest):
         x = cp.Variable((5, 2))
         y = cp.Variable((5, 2))
 
-        stacked_flattened = cp.vstack([cp.vec(x), cp.vec(y)])  # (2, 10)
+        stacked_flattened = cp.vstack([cp.vec(x, order='F'), cp.vec(y, order='F')])  # (2, 10)
         minimum = cp.min(stacked_flattened, axis=0)  # (10,)
-        reshaped_minimum = cp.reshape(minimum, (5, 2))  # (5, 2)
+        reshaped_minimum = cp.reshape(minimum, (5, 2), order='F')  # (5, 2)
 
         obj = cp.sum(reshaped_minimum)
         problem = cp.Problem(cp.Maximize(obj), [x == 1, y == 2])
@@ -2146,8 +2265,8 @@ class TestProblem(BaseTest):
                 prob.solve()
                 assert isinstance(w[0].message, FutureWarning)
                 assert str(w[0].message) == ECOS_DEPRECATION_MSG
-            
-            # No warning if ECOS solver specified.
+
+            # No warning if CLARABEL solver specified.
             with warnings.catch_warnings(record=True) as w:
-                prob.solve(solver=cp.ECOS)
+                prob.solve(solver=cp.CLARABEL)
                 assert len(w) == 0
